@@ -1,14 +1,18 @@
-import requests
 import re
+from typing import Iterator, List, Optional
 
-from typing import List, Optional, Iterator
+import requests
 
-from .codingamer import CodinGamer
 from .clash_of_code import ClashOfCode
-from .notification import Notification
-
+from .codingamer import CodinGamer
 from .endpoints import Endpoints
-from .exceptions import CodinGamerNotFound, ClashOfCodeNotFound, LoginRequired
+from .exceptions import ClashOfCodeNotFound, CodinGamerNotFound, LoginRequired
+from .leaderboard import (
+    ChallengeLeaderboard,
+    GlobalLeaderboard,
+    PuzzleLeaderboard,
+)
+from .notification import Notification
 from .utils import validate_args
 
 
@@ -68,7 +72,9 @@ class Client:
         if password == "":
             raise ValueError("Password is required")
 
-        r = self._session.post(Endpoints.CodinGamer_login, json=[email, password, True])
+        r = self._session.post(
+            Endpoints.CodinGamer_login, json=[email, password, True]
+        )
         json = r.json()
         if "id" in json and "message" in json:
             raise ValueError(f"{json['id']}: {json['message']}")
@@ -110,17 +116,23 @@ class Client:
             r = self._session.post(Endpoints.CodinGamer_id, json=[codingamer])
             json = r.json()
             if "id" in json and json["id"] == 404:
-                raise CodinGamerNotFound(f"No CodinGamer with id {codingamer!r}")
+                raise CodinGamerNotFound(
+                    f"No CodinGamer with id {codingamer!r}"
+                )
             return CodinGamer(client=self, **json)
 
         if not self._CODINGAMER_HANDLE_REGEX.match(codingamer):
-            r = self._session.post(Endpoints.Search, json=[codingamer, "en", None])
+            r = self._session.post(
+                Endpoints.Search, json=[codingamer, "en", None]
+            )
             search: List[dict] = r.json()
             users = [query for query in search if query["type"] == "USER"]
             if users:
                 handle = users[0]["id"]
             else:
-                raise CodinGamerNotFound(f"No CodinGamer with username {codingamer!r}")
+                raise CodinGamerNotFound(
+                    f"No CodinGamer with username {codingamer!r}"
+                )
         else:
             handle = codingamer
 
@@ -160,10 +172,14 @@ class Client:
                 "(regex: [0-9]{7}[0-9a-f]{32})."
             )
 
-        r = self._session.post(Endpoints.ClashOfCode, json=[clash_of_code_handle])
+        r = self._session.post(
+            Endpoints.ClashOfCode, json=[clash_of_code_handle]
+        )
         json = r.json()
         if "id" in json and "message" in json:
-            raise ClashOfCodeNotFound(f"No Clash of Code with handle {clash_of_code_handle!r}")
+            raise ClashOfCodeNotFound(
+                f"No Clash of Code with handle {clash_of_code_handle!r}"
+            )
         return ClashOfCode(client=self, **json)
 
     def get_pending_clash_of_code(self) -> Optional[ClashOfCode]:
@@ -215,6 +231,122 @@ class Client:
         if not self.logged_in:
             raise LoginRequired()
 
-        r = self._session.post(Endpoints.UnseenNotifications, json=[self.codingamer.id])
+        r = self._session.post(
+            Endpoints.UnseenNotifications, json=[self.codingamer.id]
+        )
         for notification in r.json():
             yield Notification(notification)
+
+    def get_global_leaderboard(
+        self, page: int = 1, type: str = "GENERAL", group: str = "global"
+    ) -> GlobalLeaderboard:
+        type = type.upper()
+        if type not in [
+            "GENERAL",
+            "CONTESTS",
+            "BOT_PROGRAMMING",
+            "OPTIM",
+            "CODEGOLF",
+        ]:
+            raise ValueError(
+                "type argument must be one of: GENERAL, CONTESTS, "
+                f"BOT_PROGRAMMING, OPTIM, CODEGOLF. Got: {type}"
+            )
+
+        group = group.lower()
+        if group not in [
+            "global",
+            "country",
+            "company",
+            "school",
+            "following",
+        ]:
+            raise ValueError(
+                "group argument must be one of: global, country, company, "
+                f"school, following. Got: {group}"
+            )
+
+        if (
+            group in ["country", "company", "school", "following"]
+            and not self.logged_in
+        ):
+            raise LoginRequired()
+
+        r = self._session.post(
+            Endpoints.global_leaderboard,
+            json=[
+                page,
+                type,
+                {"keyword": "", "active": False, "column": "", "filter": ""},
+                self.codingamer.public_handle if self.logged_in else "",
+                True,  # return count
+                group,
+            ],
+        )
+        return GlobalLeaderboard(self, type, group, page, r.json())
+
+    def get_challenge_leaderboard(
+        self, challenge_id: str, group: str = "global"
+    ) -> ChallengeLeaderboard:
+        group = group.lower()
+        if group not in [
+            "global",
+            "country",
+            "company",
+            "school",
+            "following",
+        ]:
+            raise ValueError(
+                "group argument must be one of: global, country, company, "
+                f"school, following. Got: {group}"
+            )
+
+        if (
+            group in ["country", "company", "school", "following"]
+            and not self.logged_in
+        ):
+            raise LoginRequired()
+
+        r = self._session.post(
+            Endpoints.challenge_leaderboard,
+            json=[
+                challenge_id,
+                self.codingamer.public_handle if self.logged_in else "",
+                group,
+                {"keyword": "", "active": False, "column": "", "filter": ""},
+            ],
+        )
+        return ChallengeLeaderboard(self, challenge_id, group, r.json())
+
+    def get_puzzle_leaderboard(
+        self, puzzle_id: str, group: str = "global"
+    ) -> PuzzleLeaderboard:
+        group = group.lower()
+        if group not in [
+            "global",
+            "country",
+            "company",
+            "school",
+            "following",
+        ]:
+            raise ValueError(
+                "group argument must be one of: global, country, company, "
+                f"school, following. Got: {group}"
+            )
+
+        if (
+            group in ["country", "company", "school", "following"]
+            and not self.logged_in
+        ):
+            raise LoginRequired()
+
+        r = self._session.post(
+            Endpoints.puzzle_leaderboard,
+            json=[
+                puzzle_id,
+                self.codingamer.public_handle if self.logged_in else "",
+                group,
+                {"keyword": "", "active": False, "column": "", "filter": ""},
+            ],
+        )
+        return PuzzleLeaderboard(self, puzzle_id, group, r.json())
